@@ -313,7 +313,7 @@ class LiveCDCopyBackend(backend.AnacondaBackend):
         # look for kernel arguments we know should be preserved and add them
         ourargs = ["speakup_synth=", "apic", "noapic", "apm=", "ide=", "noht",
             "acpi=", "video=", "vga=", "gfxpayload=", "init=", "splash=",
-            "console=", "pci=routeirq", "irqpoll", "nohdparm", "pci=",
+            "splash", "console=", "pci=routeirq", "irqpoll", "nohdparm", "pci=",
             "floppy.floppy=", "all-generic-ide", "gentoo=", "res=", "hsync=",
             "refresh=", "noddc", "xdriver=", "onlyvesa", "nvidia=", "dodmraid",
             "dmraid", "sabayonmce", "quiet", "scandelay=", "doslowusb",
